========
WaiverDB
========
WaiverDB is a companion service to `ResultsDB`_, for recording waivers against
test results.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   user-guide
   api
   waiverdb-cli
   waiverdb
   client-conf
   developer-guide
   admin-guide
   release-notes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _ResultsDB: https://pagure.io/taskotron/resultsdb
